@@ -8,7 +8,7 @@ use swc_atoms::js_word;
 use swc_common::{collections::AHashMap, util::take::Take, DUMMY_SP};
 use swc_ecma_ast::*;
 use swc_ecma_transforms::optimization::simplify::{expr_simplifier, ExprSimplifierConfig};
-use swc_ecma_utils::{ident::IdentLike, undefined, ExprExt, ExprFactory, Id};
+use swc_ecma_utils::{ident::IdentLike, undefined, ExprExt, Id};
 use swc_ecma_visit::{FoldWith, VisitMutWith};
 
 pub struct Evaluator {
@@ -97,13 +97,10 @@ impl Evaluator {
 
                 match &*t.tag {
                     Expr::Member(MemberExpr {
-                        obj: ExprOrSuper::Expr(tag_obj),
-                        prop,
-                        computed: false,
+                        obj: tag_obj,
+                        prop: MemberProp::Ident(prop),
                         ..
-                    }) if tag_obj.is_ident_ref_to("String".into())
-                        && prop.is_ident_ref_to("raw".into()) =>
-                    {
+                    }) if tag_obj.is_ident_ref_to("String".into()) && prop.sym == *"raw" => {
                         return self.eval_tpl(&t.tpl);
                     }
 
@@ -132,11 +129,14 @@ impl Evaluator {
 
             // "foo".length
             Expr::Member(MemberExpr {
-                obj: ExprOrSuper::Expr(obj),
-                prop,
-                computed: false,
+                obj,
+                prop:
+                    MemberProp::Ident(Ident {
+                        sym: js_word!("length"),
+                        ..
+                    }),
                 ..
-            }) if obj.is_lit() && prop.is_ident_ref_to("length".into()) => {}
+            }) if obj.is_lit() => {}
 
             Expr::Unary(UnaryExpr {
                 op: op!("void"), ..
@@ -178,19 +178,14 @@ impl Evaluator {
             }
 
             Expr::Member(MemberExpr {
-                span,
-                obj: ExprOrSuper::Expr(obj),
-                prop,
-                computed: false,
-                ..
-            }) => {
+                span, obj, prop, ..
+            }) if !prop.is_computed() => {
                 let obj = self.eval_as_expr(&obj)?;
 
                 let mut e = Expr::Member(MemberExpr {
                     span: *span,
-                    obj: obj.as_obj(),
+                    obj,
                     prop: prop.clone(),
-                    computed: false,
                 });
 
                 e.visit_mut_with(&mut expr_simplifier(ExprSimplifierConfig {
@@ -198,7 +193,6 @@ impl Evaluator {
                 }));
                 return Some(Box::new(e));
             }
-
             _ => {}
         }
 
